Usage
=====
.. automodule:: bohicalog
    :members:

.. automodule:: bohicalog.jsonformat
    :members:

.. automodule:: bohicalog.colors
    :members:

.. automodule:: bohicalog.version
    :members:
